==> haskell-hscolour-1.24.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.1
id: hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk
key: hscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk
license: LGPL
copyright: 2003-2016 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: 67bca39b4f9903341dd2d6b1ee7ad16e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hscolour
hs-libraries: HShscolour-1.24.1-8VIByEGMUB98gZuOLuHUQk
depends:
    base-4.10.0.0 containers-0.5.10.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.24.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.2
id: hscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
key: hscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
license: LGPL
copyright: 2003-2017 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: a7189ce0a343bf50195b6574a9387d27
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hscolour-1.24.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hscolour
hs-libraries: HShscolour-1.24.2-2hhTb9jrnCPKmvAsG3oU3G
depends:
    base-4.10.0.0 containers-0.5.10.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
